Learn R Programming

xegaDerivationTrees (version 1.0.0.6)

addE: Add an edge or a list of edges to the data frame for edges.

Description

Adds the edges of the kids of a node to the edge list.

Usage

addE(df, from, to)

Value

A Data frame for edges.

Arguments

df

Data frame for edges.

from

Integer (numerical identifier of vertex).

to

Vector of integers (numerical identifiers of kids of vertex).

See Also

Other Data frames for igraph: addV(), newE(), newV()

Examples

Run this code
df<-addE(newE(), 1, c(2, 3, 4))
print(df) 

Run the code above in your browser using DataLab