Learn R Programming

xegaDerivationTrees (version 1.0.0.6)

addV: Add a vertex to the data frame for vertices.

Description

Add a vertex to the data frame for vertices.

Usage

addV(df, id, name)

Value

A Data frame for vertices.

Arguments

df

Data frame for vertices.

id

Integer (numerical identifier of vertex).

name

Name of grammar symbol of of vertex.

See Also

Other Data frames for igraph: addE(), newE(), newV()

Examples

Run this code
df<-addV(newV(), 1, "")
print(df) 

Run the code above in your browser using DataLab