Learn R Programming

xegaDerivationTrees (version 1.0.0.6)

decodeDTsym: Decodes a derivation tree into a list of the leaf symbols of the derivation tree.

Description

Decodes a derivation tree into a list of the leaf symbols of the derivation tree.

Usage

decodeDTsym(tree, ST)

Value

List of the leaf symbols of the derivation tree.

Arguments

tree

Derivation tree.

ST

Symbol table.

See Also

Other Decoder: decodeAndFixDT(), decodeCDT(), decodeDT(), decodeTree(), leavesIncompleteDT()

Examples

Run this code
g<-compileBNF(booleanGrammar())
t1<-generateDerivationTree(sym=g$Start,sample(100, 10, replace=TRUE), G=g)
decodeDTsym(t1$tree, g$ST) 

Run the code above in your browser using DataLab